DescribeDeviceResponse class

Constructors

DescribeDeviceResponse({DateTime? firstAccessedTime, DateTime? lastAccessedTime, String? manufacturer, String? model, String? operatingSystem, String? operatingSystemVersion, String? patchLevel, DeviceStatus? status, String? username})
DescribeDeviceResponse.fromJson(Map<String, dynamic> json)
factory

Properties

firstAccessedTime → DateTime?
The date that the device first signed in to Amazon WorkLink.
final
hashCode → int
The hash code for this object.
no setterinherited
lastAccessedTime → DateTime?
The date that the device last accessed Amazon WorkLink.
final
manufacturer → String?
The manufacturer of the device.
final
model → String?
The model of the device.
final
operatingSystem → String?
The operating system of the device.
final
operatingSystemVersion → String?
The operating system version of the device.
final
patchLevel → String?
The operating system patch level of the device.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → DeviceStatus?
The current state of the device.
final
username → String?
The user name associated with the device.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited