DescribeDomainResponse class

Constructors

DescribeDomainResponse({String? acmCertificateArn, DateTime? createdTime, String? displayName, String? domainName, DomainStatus? domainStatus})
DescribeDomainResponse.fromJson(Map<String, dynamic> json)
factory

Properties

acmCertificateArn → String?
The ARN of an issued ACM certificate that is valid for the domain being associated.
final
createdTime → DateTime?
The time that the domain was added.
final
displayName → String?
The name to display.
final
domainName → String?
The name of the domain.
final
domainStatus → DomainStatus?
The current state for the domain.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited