DescribeIdentityProviderConfigurationResponse class

Constructors

DescribeIdentityProviderConfigurationResponse({String? identityProviderSamlMetadata, IdentityProviderType? identityProviderType, String? serviceProviderSamlMetadata})
DescribeIdentityProviderConfigurationResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
identityProviderSamlMetadata → String?
The SAML metadata document provided by the user’s identity provider.
final
identityProviderType → IdentityProviderType?
The type of identity provider.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceProviderSamlMetadata → String?
The SAML metadata document uploaded to the user’s identity provider.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited