DomainSummary class

The summary of the domain.

Constructors

DomainSummary({required DateTime createdTime, required String domainName, required DomainStatus domainStatus, String? displayName})
DomainSummary.fromJson(Map<String, dynamic> json)
factory

Properties

createdTime → DateTime
The time that the domain was created.
final
displayName → String?
The name to display.
final
domainName → String
The name of the domain.
final
domainStatus → DomainStatus
The status of the domain.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited