ListDevicesResponse class

Constructors

ListDevicesResponse({List<DeviceSummary>? devices, String? nextToken})
ListDevicesResponse.fromJson(Map<String, dynamic> json)
factory

Properties

devices → List<DeviceSummary>?
Information about the devices.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
The pagination token used to retrieve the next page of results for this operation. If there are no more pages, this value is null.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited